# Generated by Django 3.1.2 on 2020-10-06 06:06

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('users', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='user',
            name='identify_code',
            field=models.CharField(blank=True, max_length=12, verbose_name='identify code'),
        ),
    ]
